@@ -19,10 +19,10 @@ class ZincAsyncRequest(object):
         self.start_time = start_time
 
     def finished(self):
-        self.abstract_processor.finished(self.url, self.request_id)
+        return self.abstract_processor.finished(self.url, self.request_id)
 
     def get_response(self):
-        self.abstract_processor.wait_for_response(self.url, self.request_id, self.start_time)
+        return self.abstract_processor.wait_for_response(self.url, self.request_id, self.start_time)
 
 class ZincRequestProcessor(object):
     """Processor for Zinc API requests.
@@ -40,7 +40,7 @@ class ZincRequestProcessor(object):
     def process_async(klass, request_type, payload,
             zinc_base_url="https://api.zinc.io/v0"):
         processor = ZincAbstractProcessor()
-        return processor.post_request(payload, request_type)
+        return processor.post_request(payload, request_type, async=True)
 
 class ZincAbstractProcessor(object):
     def __init__(self, zinc_base_url="https://api.zinc.io/v0", 
@@ -89,7 +89,7 @@ class ZincAbstractProcessor(object):
         if result_json["_type"] == "error" and result_json["code"] == "request_processing":
             return False
         elif result_json["_type"] == "error":
-            raise ZincError(result)
+            raise ZincError(result_json)
         else:
             return result_json
 
