@@ -4,8 +4,8 @@ from getpass import getpass
 import sys
 import os
 import json
-import requests
 import re
+from subprocess import call
 import urllib
 import urllib2
 
@@ -114,13 +114,13 @@ class ZincWizard(object):
             "security_code": "Please input the CVV security code from your credit card",
             "end_message": "\nYou've finished entering your credit card information!"
             },
-        "write_to_zincrc": "Would you like to write the information you just entered to a configuration file (~/.zincrc) so you can make orders more easily in the future? We'll only include your shipping address and a hashed credit card token, so no confidential information will be written to your hard drive."
+        "write_to_zincrc": "Would you like to write the information you just entered to a configuration file (.zincrc) so you can make orders more easily in the future? We'll only include your shipping address and a hashed credit card token, so no confidential information will be written to your hard drive. (y)/n"
         }
 
     def __init__(self,
             retailer = "amazon",
             client_token = "public",
-            filename = "~/.zinrc",
+            filename = None,
             gift = None,
             ):
         self.retailer = retailer
@@ -135,9 +135,13 @@ class ZincWizard(object):
         self.shipping_address = None
 
     def get_stored_data(self, filename):
-        if os.path.isfile(filename):
+        default_filename = os.path.join(os.path.dirname(os.path.abspath(__file__)), "../.zincrc")
+        if filename != None and os.path.isfile(filename):
             with open(filename, 'rb') as f:
                 return json.loads(f.read())
+        elif os.path.isfile(default_filename):
+            with open(default_filename, 'rb') as f:
+                return json.loads(f.read())
         return {}
 
     def retrieve_data(self, key):
@@ -151,15 +155,17 @@ class ZincWizard(object):
                 return self.shipping_address
             else:
                 return self.get_address(key)
+        elif key == "credit_card":
+            return self.get_credit_card_information()
 
     def start(self):
         print WELCOME_BANNER
         try:
             self.start_interactive_session()
         except ZincError as e:
-            print "\nUnfortunately there seemed to be an error\n"
-            print e
-            print "\nRestarting...\n"
+            self.print_indent("\nUnfortunately there seemed to be an error\n")
+            self.print_indent(str(e))
+            self.print_indent("\nRestarting...\n")
             self.start_interactive_session()
 
     def start_interactive_session(self):
@@ -214,6 +220,7 @@ class ZincWizard(object):
         asin = self.get_asin(self.product_url)
         product_info = None
         if asin != None:
+            print call(["curl", "http://ihmage.com/" + asin + "?size=25"])
             product_info = AmazonDataFinder.get_amazon_data(asin)
         variants_response = async_response.get_response()
         response_data["variant_options_response"] = variants_response
@@ -244,7 +251,7 @@ class ZincWizard(object):
     def get_store_card(self, response_data):
         cc_token = self.retrieve_data("cc_token")
         if cc_token == None:
-            cc_data = self.get_credit_card_information()
+            cc_data = self.retrieve_data("credit_card")
             self.billing_address = self.retrieve_data("billing_address")
             print "\nProcessing request...\n"
             store_card_response = ZincRequestProcessor.process("store_card", {
@@ -311,12 +318,13 @@ class ZincWizard(object):
         self.print_indent("Total:            %s" % format_price(components["total"]))
 
     def write_to_zincrc(self):
-        if self.prompt_boolean(self.PROMPTS["write_to_zincrc"]):
+        filename = os.path.join(os.path.dirname(os.path.abspath(__file__)), "../.zincrc")
+        if not os.path.isfile(filename) and self.prompt_boolean(self.PROMPTS["write_to_zincrc"]):
             data = {
                 "shipping_address": self.shipping_address,
-                "cc_token": self.cc_token
+                "cc_token": self.retrieve_data("cc_token")
                 }
-            with open("~/.zincrc", 'wb') as f:
+            with open(filename, 'w+') as f:
                 f.write(json.dumps(data))
 
     def get_asin(self, product_url):
@@ -482,6 +490,5 @@ class AmazonDataFinder(object):
         except Exception, err:
             return False
 
-
 if __name__ == '__main__':
     ZincWizard().start()
